@@ -38,9 +38,9 @@ class NpyAppendArray:
         if os.path.isfile(self.filename):
             with open(self.filename, mode="rb+") as fp:
                 magic = np.lib.format.read_magic(fp)
-        if magic != (2, 0):
-            arr = np.load(self.filename)
-            self.write(arr)
+            if magic != (2, 0):
+                arr = np.load(self.filename)
+                self.write(arr)
 
     def __create_header_bytes(self, spare_space = True):
         from struct import pack
@@ -215,12 +215,15 @@ def np_save(path, value, mode = 'w'):
     if not value.flags.c_contiguous:
         value = np.ascontiguousarray(value)
     
+    mode = mode[0].lower()
     with NpyAppendArray(path) as f:
-        if mode == 'a':
+        if mode == 'a' and os.path.exists(path):
             f.make_file_appendable()
             f.append(value)
-        elif mode == 'w':
+        elif mode in 'wa':
             f.write(value)
+        else:
+            raise ValueError('mode "%s" needs to be "a" or "w"'%mode)
     return path
 
 def pd_to_npy(value, path, mode = 'w', check = True):
@@ -317,7 +320,8 @@ def pd_to_npy(value, path, mode = 'w', check = True):
     if path.endswith(_npy):
         path = path[:-len(_npy)]    
     
-    jname = path +'/%s%s'%('metadata', _json)    
+    jname = path +'/%s%s'%('metadata', _json)  
+    mode = mode[0].lower()
     if check and mode == 'a' and os.path.isfile(jname):
         with open(jname, 'r') as fp:
             j = json.load(fp)
@@ -348,7 +352,7 @@ def pd_to_npy(value, path, mode = 'w', check = True):
 
 pd_to_npy.output = ['path', 'columns', 'index', 'latest']
 
-def pd_read_npy(path, columns = None, index = None, latest = None):
+def pd_read_npy(path, columns = None, index = None, latest = None, **kwargs):
     """
     reads a pandas dataframe/series from a path directory containing npy files
 
@@ -378,7 +382,7 @@ def pd_read_npy(path, columns = None, index = None, latest = None):
         index = index or j['index']    
     res = pd.DataFrame(data, index_data)
     res.index.name = index
-    if isinstance(columns, str):
+    if not isinstance(columns, (list, tuple)):
         res = res[0]
     else:
         res.columns = columns
